==> miniorange_saml_idp-8.x-1.0.tar.gz: miniorange_saml_idp/src/Form/MiniorangeIDPSetup.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml_idp\Form\MiniorangeIDPSetup.
 */

namespace Drupal\miniorange_saml_idp\Form;
use Drupal\miniorange_saml_idp\MiniorangeSAMLCustomer;
use Drupal\miniorange_saml_idp\AESEncryption;



use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;

class MiniorangeIDPSetup extends FormBase {

 public function getFormId() {
    return 'miniorange_saml_idp_setup';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

   
  if (\Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_email') == NULL || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_id') == NULL
    || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_token') == NULL || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_api_key') == NULL) {
    $form['header'] = array(
      '#markup' => '<center><h3>You need to register with miniOrange before using this module.</h3></center>',
    );

    return $form;
  }
   

  global $base_url;
  $url = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_base_url');
  $issuer = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_entity_id');
  
  $b_url = isset($url) && !empty($url)? $url:$base_url;
  $issuer_id = isset($issuer) && !empty($issuer)? $issuer:$base_url;
  
  
  $acs_url = $b_url . '/samlassertion';
  $logout_url = $b_url . '/user/logout';
  
  $form['markup_idp_header'] = array(
    '#markup' => '<h3>Configure Identity Provider</h3>',
  );
  
  $form['markup_idp_note'] = array(
    '#markup' => '<div>Please note down the following information from your Service Provider'
  . ' and keep it handy to configure your Identity Provider.</div>',
  );
  
  $form['markup_idp_list'] = array(
    '#markup' => '<b><ol><li>SP Entity ID / Issuer</li>'
  . ' <li>ACS URL</li>'
  . ' <li>X.509 Certificate for Signing if you are using HTTP-POST Binding. [This is a'
  . ' <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">premium</a> feature]</li>'
  . ' <li>X.509 Certificate for Encryption. [This is a'
  . ' <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">premium</a> feature]</li>'
  . ' <li>NameID Format</li></ol></b><br />',
  );
  
  if(!isset($mo_admin_email)){
    $form['markup_saml_idp_disabled'] = array(
      '#markup' => '<div style="position: absolute;margin: 7% 33%;font-weight: bold;z-index: 1;">'
    . ' </div><div style="background-color: rgba(218, 218, 218, 0);padding: 2%;opacity: 0.3;">',
    );
  }
  
  $form['miniorange_saml_idp_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Service Provider Name'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_name'),
    '#attributes' => array('placeholder' => 'Service Provider Name'),
    '#required' => TRUE,
  );

  $form['miniorange_saml_idp_entity_id'] = array(
    '#type' => 'textfield',
    '#title' => t('SP Entity ID or Issuer'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_entity_id'),
    '#attributes' => array('placeholder' => 'SP Entity ID or Issuer'),
    '#required' => TRUE,
  );

  $form['miniorange_saml_idp_acs_url'] = array(
    '#type' => 'textfield',
    '#title' => t('ACS URL'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_acs_url'),
    '#attributes' => array('placeholder' => 'ACS URL'),
    '#required' => TRUE,
  );
  
  $form['miniorange_saml_idp_relay_state'] = array(
    '#type' => 'textfield',
    '#title' => t('Relay State'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_relay_state'),
    '#attributes' => array('placeholder' => 'Relay State (optional)'),
    '#required' => FALSE,
  );
  
  $form['markup_idp_certificate_signed'] = array(
    '#markup' => '<div><b>x.509 Certificate (Optional)[For Signed Request]:</b> <span style="padding-left:60px;">This is a premium feature.'
  . ' Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Licensing</a> Tab'
  . ' to learn more.</span></div><br />',
  );
  
  $form['markup_idp_certificate_encrypted'] = array(
    '#markup' => '<div><b>x.509 Certificate (Optional)[For Encrypted Assertion]:</b> <span style="padding-left:30px;">'
  . ' This is a premium feature. Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Licensing</a>' 
  . ' Tab to learn more.</span></div>',
  );
  
  $form['miniorange_saml_idp_nameid_format'] = array(
    '#type' => 'select',
  '#title' => t('NameID Format:'),
  '#options' => array(
    '1.1:nameid-format:emailAddress' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'),
    '1.1:nameid-format:unspecified' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'),
    '2.0:nameid-format:transient' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:transient'),
    '2.0:nameid-format:persistent' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:persistent'),
  ),
  '#default_value' =>\Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_nameid_format'),
  '#description' => t('(<b>NOTE:</b> urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress is selected by default)'),
  );
  
  $form['markup_idp_response_signed'] = array(
    '#markup' => '<b>Response Signed:</b> <span style="padding-left:60px;">This is a premium feature.'
  . ' Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Licensing</a>'
  . ' Tab to learn more.</span><br /><br />',
  );
  
  $form['miniorange_saml_idp_assertion_signed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Assertion Signed (Check If you want to sign SAML Assertion.)'),
   
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_assertion_signed'),
  );
  
  
  $form['markup_idp_encrypted_assertion'] = array(
    '#markup' => '<b>Encrypted Assertion:</b> <span style="padding-left:40px;">This is a premium feature.'
  . ' Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Licensing</a>'
  . ' Tab to learn more.</span><br /><br /><br />',
  ); 
  
  $form['miniorange_saml_idp_config_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Configuration'),
  );
$testConfigUrl = "\'" . $this->getTestUrl() . "\'";

  $form['miniorange_saml_idp_test_config_button'] = array('#attached' => array(
  'library' => 'miniorange_saml_idp/miniorange_saml_idp.test',
  ),
    '#markup' => '<a id="testConfigButton" class="btn btn-primary btn-large" style="padding:6px 12px;" onclick="testIdpConfig($testConfigUrl);">Test Configuration</a><br><br>'
  );
  
  $form['miniorange_saml_idp_config_delete'] = array(
    '#type' => 'submit',
    '#value' => t('Delete Configuration'),
    '#submit' => array('::miniorange_saml_idp_delete_idp_config'),
  );
  
  return $form;
 }

 function getTestUrl() {
  global $base_url;
  $testUrl = $base_url . '/?q=testConfig';

  return $testUrl; 
 }

 
 function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
  global $base_url;
  $mo_admin_email = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_customer_admin_email');
  $sp_name = $form['miniorange_saml_idp_name']['#value'];
  $issuer = $form['miniorange_saml_idp_entity_id']['#value'];
  $acs_url = $form['miniorange_saml_idp_acs_url']['#value'];
  $relay_state = $form['miniorange_saml_idp_relay_state']['#value'];
  $nameid_format = $form['miniorange_saml_idp_nameid_format']['#value'];
  $is_assertion_signed = $form['miniorange_saml_idp_assertion_signed']['#value'] == 1 ? TRUE : FALSE;
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_name', $sp_name)->save();
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_entity_id', $issuer)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_acs_url', $acs_url)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_relay_state', $relay_state)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_nameid_format', $nameid_format)->save();
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_assertion_signed', $is_assertion_signed)->save();
  
  drupal_set_message(t('Your Service Provider Configuration are successfully saved. You can click on Test Configuration button below to test these configurations.'));

 }
 
 public function miniorange_saml_idp_delete_idp_config($form, &$form_state){
  
\Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_name','')->save();
 
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_entity_id','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_acs_url','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_relay_state','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_nameid_format','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_assertion_signed','')->save();


  drupal_set_message(t('Your Service Provider Configuration is successfully deleted.'));
  }
}

==> miniorange_saml_idp-8.x-1.1.tar.gz: miniorange_saml_idp/src/Form/MiniorangeIDPSetup.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml_idp\Form\MiniorangeIDPSetup.
 */

namespace Drupal\miniorange_saml_idp\Form;
use Drupal\miniorange_saml_idp\MiniorangeSAMLCustomer;
use Drupal\miniorange_saml_idp\AESEncryption;



use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;

class MiniorangeIDPSetup extends FormBase {

 public function getFormId() {
    return 'miniorange_saml_idp_setup';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

   
  if (\Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_email') == NULL || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_id') == NULL
    || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_token') == NULL || \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_api_key') == NULL) {
    $form['header'] = array(
      '#markup' => '<center><h3>You need to register with miniOrange before using this module.</h3></center>',
    );

    return $form;
  }
   

  global $base_url;
  $url = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_base_url');
  $issuer = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_entity_id');
  
  $b_url = isset($url) && !empty($url)? $url:$base_url;
  $issuer_id = isset($issuer) && !empty($issuer)? $issuer:$base_url;
  $acs_url = $b_url . '/samlassertion';
  $logout_url = $b_url . '/user/logout';
  
  $form['markup_idp_header'] = array(
    '#markup' => '<h2>Configure Identity Provider</h2><hr>',
  );
  
  $form['markup_idp_note'] = array(
    '#markup' => '<br><div>Please note down the following information from your Service Provider'
  . ' and keep it handy to configure your Identity Provider.</div>',
  );
  
  $form['markup_idp_list'] = array(
    '#markup' => '<b><ol><li>SP Entity ID / Issuer</li>'
  . ' <li>ACS URL</li>'
  . ' <li>X.509 Certificate for Signing if you are using HTTP-POST Binding. [This is a'
  . ' <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Premium</a> feature]</li>'
  . ' <li>X.509 Certificate for Encryption. [This is a'
  . ' <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing">Premium</a> feature]</li>'
  . ' <li>NameID Format</li></ol></b><br />',
  );



  if(!isset($mo_admin_email)){
    $form['markup_saml_idp_disabled'] = array(
      '#markup' => '<div style="position: absolute;margin: 7% 33%;font-weight: bold;z-index: 1;">'
    . ' </div><div style="background-color: rgba(218, 218, 218, 0);padding: 2%;opacity: 0.3;">',
    );
  }
  
  $form['miniorange_saml_idp_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Service Provider Name'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_name'),
    '#attributes' => array('placeholder' => 'Service Provider Name'),
    '#required' => TRUE,
  );

  $form['miniorange_saml_idp_entity_id'] = array(
    '#type' => 'textfield',
    '#title' => t('SP Entity ID or Issuer'),
    '#description' => t('<b>Note :</b> You can find the EntityID in Your SP-Metadata XML file enclosed in <code>EntityDescriptor</code> tag having attribute as <code>entityID</code>.'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_entity_id'),
    '#attributes' => array('placeholder' => 'SP Entity ID or Issuer'),
    '#required' => TRUE,
  );

  $form['miniorange_saml_idp_nameid_format'] = array(
    '#type' => 'select',
    '#title' => t('NameID Format:'),
    '#options' => array(
        '1.1:nameid-format:emailAddress' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'),
        '1.1:nameid-format:unspecified' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'),
        '2.0:nameid-format:transient' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:transient'),
        '2.0:nameid-format:persistent' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:persistent'),
     ),
    '#default_value' =>\Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_nameid_format'),
    '#description' => t('(<b>NOTE:</b> urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress is selected by default)'),
  );

  $form['miniorange_saml_idp_acs_url'] = array(
    '#type' => 'textfield',
    '#title' => t('ACS URL'),
    '#description' => t('<b>Note :</b> You can find the SAML Login URL in Your SP-Metadata XML file enclosed in <code>AssertionConsumerService </code> tag having attribute as <code>Location</code>.'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_acs_url'),
    '#attributes' => array('placeholder' => 'ACS URL'),
    '#required' => TRUE,
  );
  
  $form['miniorange_saml_idp_relay_state'] = array(
    '#type' => 'textfield',
    '#title' => t('Relay State'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_relay_state'),
    '#attributes' => array('placeholder' => 'Relay State (optional)'),
    '#required' => FALSE,
  );



  $form['miniorange_saml_idp_x509_certificate_request'] = array(
     '#type' => 'textarea',
     '#title' => t('x.509 Certificate Value  <b>[Note: For Signed Request.] </b><a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing"> [Premium]</a>'),
     '#cols' => '10',
     '#rows' => '5',
     '#attributes' => array('placeholder' => 'Enter x509 Certificate Value'),
     '#disabled' => TRUE,
  );


  $form['markup_1'] = array(
     '#markup' => '<b>NOTE:</b> Format of the certificate:<br><b>-----BEGIN CERTIFICATE-----<br>'
      .'XXXXXXXXXXXXXXXXXXXXXXXXXXX<br>-----END CERTIFICATE-----</b>'
  );

  $form['miniorange_saml_idp_x509_certificate_assertion'] = array(
      '#type' => 'textarea',
      '#title' => t('x.509 Certificate Value <b>[Note: For Encrypted Assertion.]</b> <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing"> [Premium]</a>'),
      '#cols' => '10',
      '#rows' => '5',
      '#attributes' => array('placeholder' => 'Enter x509 Certificate Value'),
      '#disabled' => TRUE,
  );


  $form['markup_2'] = array(
      '#markup' => '<b>NOTE:</b> Format of the certificate:<br><b>-----BEGIN CERTIFICATE-----<br>'
       .'XXXXXXXXXXXXXXXXXXXXXXXXXXX<br>-----END CERTIFICATE-----</b>'
  );




  $form['miniorange_saml_idp_response_signed'] = array(
    '#markup' => '<br>',
    '#type' => 'checkbox',
    '#title' => t('<b>Response Signed:</b> This is a <b>Premium</b> feature.'
    . ' Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing"><b>Licensing</b></a>'
    . ' Tab to learn more.'),
    '#disabled' => TRUE,
  );


  $form['miniorange_saml_idp_encrypt_signed'] = array(
    '#type' => 'checkbox',
    '#title' => t('<b>Encrypted Assertion:</b> This is a <b>Premium</b> feature.'
    . ' Check <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/licensing"><b>Licensing</b></a>'
    . ' Tab to learn more.'),
    '#disabled' => TRUE,
  );

  $form['miniorange_saml_idp_assertion_signed'] = array(
    '#type' => 'checkbox',
    '#title' => t('<b>Assertion Signed</b> (Check If you want to sign SAML Assertion.)'),
    '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_assertion_signed'),
  );

  $form['miniorange_saml_idp_buttons'] = array(
    '#markup' => '<br><br>'
  );

  $form['miniorange_saml_idp_config_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Configuration'),
  );

  $form['miniorange_saml_idp_config_delete'] = array(
     '#type' => 'submit',
     '#value' => t('Delete Configuration'),
     '#submit' => array('::miniorange_saml_idp_delete_idp_config'),
  );

  $testConfigUrl = "\'" . $this->getTestUrl() . "\'";
  $form['miniorange_saml_idp_test_config_button'] = array (
      '#attached' => array(
         'library' => 'miniorange_saml_idp/miniorange_saml_idp.test',
     ),
      '#markup' => '<a id="testConfigButton" class="btn btn-primary btn-sm" style="padding:6px 12px;" onclick="testIdpConfig($testConfigUrl);"><b>Test Configuration</b></a><br><br>',
  );
  


  return $form;
 }

 function getTestUrl() {
  global $base_url;
  $testUrl = $base_url . '/?q=testConfig';

  return $testUrl; 
 }

 
 function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
  global $base_url;
  $mo_admin_email = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_customer_admin_email');
  $sp_name = $form['miniorange_saml_idp_name']['#value'];
  $issuer = $form['miniorange_saml_idp_entity_id']['#value'];
  $acs_url = $form['miniorange_saml_idp_acs_url']['#value'];
  $relay_state = $form['miniorange_saml_idp_relay_state']['#value'];
  $nameid_format = $form['miniorange_saml_idp_nameid_format']['#value'];
  $is_assertion_signed = $form['miniorange_saml_idp_assertion_signed']['#value'] == 1 ? TRUE : FALSE;
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_name', $sp_name)->save();
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_entity_id', $issuer)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_acs_url', $acs_url)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_relay_state', $relay_state)->save();
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_nameid_format', $nameid_format)->save();
  
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_assertion_signed', $is_assertion_signed)->save();
  
  drupal_set_message(t('Your Service Provider Configuration are successfully saved. You can click on Test Configuration button below to test these configurations.'));

 }
 
 public function miniorange_saml_idp_delete_idp_config($form, &$form_state){
  
\Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_name','')->save();
 
  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_entity_id','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_acs_url','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_relay_state','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_nameid_format','')->save();

  \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_assertion_signed','')->save();


  drupal_set_message(t('Your Service Provider Configuration is successfully deleted.'));
  }
}
